
## Swagger

+ ROTB: [Rates Option Trade Builder V1 API](https://analytics-api.sgmarkets.com/rotb/)

## Contacts

### Research

+ KURPIEL Adam MarkGrsRfcRat  
Adam.KURPIEL@sgcib.com  
+33 1 42 13 63 42

+ FERRET Kevin MarkDir  
kevin.ferret@sgcib.com  
+44 20 7676 7073

+ BRAIZINHA Bruno MarkGrsRat  
bruno.braizinha@sgcib.com  
+44 20 7676 7073

+ UNGARI Sandrine MarkGrsStgCaq  
sandrine.ungari@sgcib.com  
+44 20 7762 5214

### Sales

+ AUGIER Cesar MarkFicSlsRatGmo  
Cesar.augier@sgcib.com  
+44 20 7676 7758

+ CARUSO Alessandro MarkFicSlsRatGmo  
alessandro.caruso@sgcib.com  
+44 20 7676 7992

+ SJOENTOFT Emil MarkFicSlsRatNor  
emil.sjoentoft@sgcib.com  
+44 20 7676 5456

+ UNTERSPERGER Alexander MarkFicSlsRatGer  
alexander.untersperger@sgcib.com  
+44 20 7676 7451

+ GHULAMALI Naeem MarkFicSlsRatUki  
naeem.ghulamali@sgcib.com  
+44 20 7676 7321

### Python

+ FERRET Kevin MarkDir  
kevin.ferret@sgcib.com  
+44 20 7676 7073

+ BORDERIES Olivier GbisCdo  
olivier.borderies@sgcib.com  
+33 1 42 13 61 04

### API

+ CARISTAN Aurelien MarkAsiDir  
aurelien.caristan@sgcib.com  
+81 3 6777 8016

+ RIVET Nicolas GbisCdo  
nicolas.rivet@sgcib.com  
+33 1 57 29 04 58
